@@ -6,7 +6,7 @@
 
 //
 //    BEDOPS
-//    Copyright (C) 2011-2018 Shane Neph, Scott Kuehn and Alex Reynolds
+//    Copyright (C) 2011-2020 Shane Neph, Scott Kuehn and Alex Reynolds
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -244,6 +244,9 @@ char *           STARCH_generateJSONMetadata(const Metadata *md,
                                                  const char *note,
                                               const Boolean headerFlag);
 
+int              STARCH_JSONMetadataExists(FILE **fp,
+                                     const char *fn);
+
 int              STARCH_readJSONMetadata(json_t **metadataJSON,
                                            FILE **fp, 
                                      const char *fn, 
